package com.install4j.api.beans;

/**
 * Variable replacement mode for string properties that are used in regular expressions.
 * The enumerated class is used as a parameter to {@link AbstractBean#replaceVariables(String, ReplacementMode)}.
 */
public class ReplacementMode {

    /**
     * Normal replacement like in {@link AbstractBean#replaceVariables(String)}.
     */
    public static final ReplacementMode PLAIN = new ReplacementMode();

    /**
     * Only i18n variables like ${i18n:myKey} will be replaced.
     */
    public static final ReplacementMode I18N_ONLY = new ReplacementMode();

    /**
     * The property is used as a regular expression. All special characters are quoted.
     */
    public static final ReplacementMode REGEXP_MATCH = new ReplacementMode();

    /**
     * The property is used as a replacement part of a regular expression. Backslashes and dollar signs are quoted.
     */
    public static final ReplacementMode REGEXP_REPLACEMENT = new ReplacementMode();

    /**
     * The property is used while replacing text directly in a Java properties file.
     * See the Javadoc for java.util.Properties for more information on the encoding of
     * a Java properties file. 
     */
    public static final ReplacementMode PROPERTIES_FILE = new ReplacementMode();

}
