package com.install4j.api.formcomponents;

import javax.swing.*;

/**
 * Represents the created GUI components for a form component.
 * If the installer or uninstaller is running in GUI mode, the framework will call the
 * <tt>createLeftComponent</tt>, <tt>createCenterComponent</tt> and <tt>createRightComponent</tt>
 * of a form component after instantiating it. These three components of which the left and right components
 * may be <tt>null</tt> form the <b>component tuple</b> of the form component.
 * <p>
 * A component tuple can be obtained for every form component via the form environment.
 * </p>
 * @see FormEnvironment#getComponentTuple(FormComponent) 
 */
public interface ComponentTuple {
    /**
     * Return the left GUI component created by <tt>FormComponent.createLeftComponent</tt>.
     * @return the left GUI component
     * @see FormComponent#createLeftComponent()
     */
    JComponent getLeftComponent();
    /**
     * Return the center GUI component created by <tt>FormComponent.createCenterComponent</tt>.
     * @return the center GUI component
     * @see FormComponent#createCenterComponent()
     */
    JComponent getCenterComponent();
    /**
     * Return the right GUI component created by <tt>FormComponent.createRightComponent</tt>.
     * @return the right GUI component
     * @see FormComponent#createRightComponent()
     */
    JComponent getRightComponent();
}
